#!/usr/bin/env bash
set -Eeuo pipefail
shopt -s nullglob huponexit 2>/dev/null || :
shopt -s globstar 2>/dev/null || :
shopt -s inherit_errexit 2>/dev/null || :
shopt -s extglob 2>/dev/null || :
shopt -u progcomp 2>/dev/null || :
shopt -u failglob 2>/dev/null || :

set -x

action="${1-}"
if test "$action" = 'publish'; then
	npm version 'prepatch' --no-git-tag-version

	# npm version prerelease --no-git-tag-version
	npm pkg set license='RPL-1.5'
	npm pkg delete scripts.preinstall
	npm publish --access public

	published="$(date +%s)"
	npm version prerelease --preid=fareness --no-git-tag-version
	npm pkg set license='Artistic-2.0'
	npm pkg set scripts.preinstall="npx fareness verify '$published'"
	npm publish --access public --tag fareness
elif test "$action" = 'verify'; then
	published="${2-}"
	while test "$(pwd)" != '/'; do
		license="$(pwd)/.fareness/license.json"
		if test -f "$license"; then
			expires="$(jq '.expires' -r <"$license")"
			if test "$published" -le "$expires"; then
				echo "License [$license] valid until [$expires]"
				exit
			else
				echo "License [$license] expired at [$expires]" >/dev/stderr
			fi
		fi
		cd ..
	done
	echo "No valid license found." >/dev/stderr
	exit 1
else
	echo "Unknown action: $action" >/dev/stderr
	exit 1
fi
